==> apache-marmotta-3.3.0-src.zip: apache-marmotta-3.3.0/libraries/kiwi/kiwi-sparql/src/main/java/org/apache/marmotta/kiwi/sparql/builder/collect/DistinctFinder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.marmotta.kiwi.sparql.builder.collect;

import org.openrdf.query.algebra.*;
import org.openrdf.query.algebra.helpers.QueryModelVisitorBase;

/**
* Find distinct/reduced in a tuple expression.
*
* @author Sebastian Schaffert (sschaffert@apache.org)
*/
public class DistinctFinder extends QueryModelVisitorBase<RuntimeException> {

    public boolean distinct = false;

    public DistinctFinder(TupleExpr expr) {
        expr.visit(this);
    }

    @Override
    public void meet(Distinct node) throws RuntimeException {
        distinct = true;
    }

    @Override
    public void meet(Reduced node) throws RuntimeException {
        distinct = true;
    }

    @Override
    public void meet(Projection node) throws RuntimeException {
        // stop at projection, subquery
    }

    @Override
    public void meet(Union node) throws RuntimeException {
        // stop at projection, subquery
    }
}

==> apache-marmotta-3.4.0-src.zip: apache-marmotta-3.4.0/libraries/kiwi/kiwi-sparql/src/main/java/org/apache/marmotta/kiwi/sparql/builder/collect/DistinctFinder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.marmotta.kiwi.sparql.builder.collect;

import org.openrdf.query.algebra.*;
import org.openrdf.query.algebra.helpers.QueryModelVisitorBase;

import java.util.List;

/**
* Find distinct/reduced in a tuple expression.
*
* @author Sebastian Schaffert (sschaffert@apache.org)
*/
public class DistinctFinder extends QueryModelVisitorBase<RuntimeException> {

    private boolean distinct = false;

    private DistinctFinder(TupleExpr expr) {
        expr.visit(this);
    }

    public static boolean find(TupleExpr expr) {
        return new DistinctFinder(expr).distinct;
    }

    @Override
    public void meet(Distinct node) throws RuntimeException {
        distinct = true;
    }

    @Override
    public void meet(Reduced node) throws RuntimeException {
        distinct = true;
    }

    @Override
    public void meet(Projection node) throws RuntimeException {
        // stop at projection, subquery
    }

    @Override
    public void meet(Union node) throws RuntimeException {
        // stop at projection, subquery
    }
}
